[asterisk-scf-commits] asterisk-scf/release/cmake.git branch "master" updated.
Commits to the Asterisk SCF project code repositories
asterisk-scf-commits at lists.digium.com
Thu Oct 28 11:40:42 CDT 2010
branch "master" has been updated
via 42917e1074f7bf2d3a0e1bd2f3383b57ec1349cf (commit)
from 05186219f6561c157b0a149b3a65a4a421b1f651 (commit)
Summary of changes:
AsteriskSCF.cmake | 5 +++--
1 files changed, 3 insertions(+), 2 deletions(-)
- Log -----------------------------------------------------------------
commit 42917e1074f7bf2d3a0e1bd2f3383b57ec1349cf
Author: David M. Lee <dlee at digium.com>
Date: Thu Oct 28 11:11:33 2010 -0500
Fixing Mac build when not using MacPorts.
diff --git a/AsteriskSCF.cmake b/AsteriskSCF.cmake
index 9b12ca0..41548e8 100644
--- a/AsteriskSCF.cmake
+++ b/AsteriskSCF.cmake
@@ -275,8 +275,9 @@ function(asterisk_scf_project NAME ICE_VERSION)
set(CMAKE_CXX_FLAGS_DEBUG "-g3 -Wall")
endif()
find_ICE_CXX()
- if(APPLE)
- # On Mac, libIce is libZeroCIce
+ # On MacPorts, libIce is libZeroCIce. Everywhere else, it's libIce.
+ string(REGEX MATCH "^/opt/local" matches_macports "${ICE_DIR}")
+ if(APPLE AND matches_macports)
find_ICE_CXX_library(ZeroCIce)
set(ICE_CXX_LIB_Ice ${ICE_CXX_LIB_ZeroCIce})
else()
-----------------------------------------------------------------------
--
asterisk-scf/release/cmake.git
More information about the asterisk-scf-commits
mailing list